# Python wrapper for Terraform null provider

This is a Python wrapper for Terraform null provider. Using `terraform-null-provider-wrapper` you can install Terraform's null provider using Pipenv or Pip, instead of manually downloading, unzipping and installing it.

## Usage

```sh
pip install terraform-null-provider-wrapper

```

## License

This project is [MIT Licensed](LICENSE).
